@@ -15,7 +15,11 @@ class LppFrame(object):
     Attributes:
         data (list): a list of LppData objects
     """
+
     def __init__(self, data=None):
+        """Create a LppFrame object with (optional)
+        a list of LppData elements `data`
+        """
         self.data = data or []
         if not isinstance(self.data, list):
             raise AssertionError()
@@ -34,6 +38,17 @@ class LppFrame(object):
         out = out + "])"
         return out
 
+    def __len__(self):
+        """Return number of data elements in a LppFrame"""
+        return len(self.data)
+
+    def __iter__(self):
+        """Return an iterator over all data elements in a LppFrame"""
+        count = 0
+        while count < len(self.data):
+            yield self.data[count]
+            count += 1
+
     @classmethod
     def from_bytes(cls, buf):
         """Parse LppFrame from a given byte string"""
@@ -85,6 +100,11 @@ class LppFrame(object):
         aout = LppData(channel, 3, (value, ))
         self.data.append(aout)
 
+    def add_generic(self, channel, value):
+        """Create and add a generic 4-byte unsigned integer LppData"""
+        din = LppData(channel, 100, (value, ))
+        self.data.append(din)
+
     def add_luminosity(self, channel, value):
         """Create and add an illuminance sensor LppData"""
         lux = LppData(channel, 101, (value, ))
@@ -105,6 +125,11 @@ class LppFrame(object):
         hum = LppData(channel, 104, (value, ))
         self.data.append(hum)
 
+    def add_unix_time(self, channel, value):
+        """Create and add a unix time sensor LppData"""
+        timestamp = LppData(channel, 133, (value, ))
+        self.data.append(timestamp)
+
     def add_accelerometer(self, channel, x, y, z):
         """Create and add a accelerometer sensor LppData"""
         acc = LppData(channel, 113, (x, y, z, ))
